from cqu_kb.__main__ import main, console_main
from cqu_kb.utils import check_update

__all__ = ["main", "console_main"]

check_update("cqu-kb")
